==> qtjambi-script-debuginfo-macos-5.15.18.jar: sources/QtJambiScript/QScriptable_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScript/qscriptable.h>
#include <QtCore/QVariant>
#include <QtScript/qscriptcontext.h>
#include <QtScript/qscriptengine.h>
#include <QtScript/qscriptvalue.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScriptable(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScriptable")
    QScriptable *_ptr = reinterpret_cast<QScriptable *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QScriptable_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QScriptable *__qt_this = new(__qtjambi_ptr) QScriptable();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QScriptable
void __qt_destruct_QScriptable(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScriptable")
    reinterpret_cast<QScriptable*>(ptr)->~QScriptable();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScriptable::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_initialize_1native__Lio_qt_script_QScriptable_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScriptable::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScriptable_0, sizeof(QScriptable), typeid(QScriptable), false, &deleter_QScriptable, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScriptable::argument(int)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_argument_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::argument(int)const", __qt_this)
        QScriptValue __qt_return_value = __qt_this->QScriptable::argument(static_cast<int>(index0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptable::argumentCount()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_argumentCount_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::argumentCount()const", __qt_this)
        __java_return_value = __qt_this->QScriptable::argumentCount();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptable::context()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_context_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::context()const", __qt_this)
        QScriptContext* __qt_return_value = __qt_this->QScriptable::context();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptable::engine()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_engine_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::engine()const", __qt_this)
        QScriptEngine* __qt_return_value = __qt_this->QScriptable::engine();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptable::thisObject()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_thisObject_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::thisObject()const", __qt_this)
        QScriptValue __qt_return_value = __qt_this->QScriptable::thisObject();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QScriptable(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QScriptable>("QScriptable", "io/qt/script/QScriptable");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScriptable, {
        ConstructorInfo(&__qt_construct_QScriptable_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScriptable);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-script-debuginfo-macos-5.15.20.jar: sources/QtJambiScript/QScriptable_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScript/qscriptable.h>
#include <QtCore/QVariant>
#include <QtScript/qscriptcontext.h>
#include <QtScript/qscriptengine.h>
#include <QtScript/qscriptvalue.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScriptable(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScriptable")
    QScriptable *_ptr = reinterpret_cast<QScriptable *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QScriptable()
void __qt_construct_QScriptable(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScriptable()")
    Q_UNUSED(__java_arguments)
    QScriptable *__qt_this = new(__qtjambi_ptr) QScriptable();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QScriptable::QScriptable()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_initialize_1native__Lio_qt_script_QScriptable_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScriptable::QScriptable()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScriptable, sizeof(QScriptable), typeid(QScriptable), false, &deleter_QScriptable, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QScriptable
void __qt_destruct_QScriptable(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScriptable")
    reinterpret_cast<QScriptable*>(ptr)->~QScriptable();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScriptable::argument(int)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_argument_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::argument(int)const", __qt_this)
        QScriptValue __qt_return_value = __qt_this->QScriptable::argument(static_cast<int>(index0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptable::argumentCount()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_argumentCount_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::argumentCount()const", __qt_this)
        __java_return_value = __qt_this->QScriptable::argumentCount();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptable::context()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_context_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::context()const", __qt_this)
        QScriptContext* __qt_return_value = __qt_this->QScriptable::context();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptable::engine()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_engine_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::engine()const", __qt_this)
        QScriptEngine* __qt_return_value = __qt_this->QScriptable::engine();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptable::thisObject()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptable_00024Impl_thisObject_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptable *__qt_this = QtJambiAPI::interfaceFromNativeId<QScriptable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptable::thisObject()const", __qt_this)
        QScriptValue __qt_return_value = __qt_this->QScriptable::thisObject();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QScriptable(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QScriptable>("QScriptable", "io/qt/script/QScriptable");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScriptable, {
        ConstructorInfo(&__qt_construct_QScriptable, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScriptable);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
